#include <pi-memo.h>
#include "../jpilot_src/libplugin.h"
#include "pytype_basics.h"

extern PyObject* PyPiMemo_New();
extern PyObject* PyPiMemo_Wrap(struct Memo*, PCRecType, unsigned int, unsigned char,
				 int, void*, PyObject *);

extern PyTypeObject MemoType;

#define PyPiMemo_Check(v)          PyObject_TypeCheck(v, &MemoType)
#define PyPiMemo_CheckExact(v)     ((v)->ob_type == &MemoType)

typedef struct {
  PyObject_HEAD
  PyObject_JPTYPE
  struct Memo a;
} PyPiMemo;
